from google.protobuf import descriptor_pb2 as _descriptor_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class TableType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    DEFAULT_TABLE_TYPE: _ClassVar[TableType]
    SQL_TABLE: _ClassVar[TableType]
    VALUE_TABLE: _ClassVar[TableType]
DEFAULT_TABLE_TYPE: TableType
SQL_TABLE: TableType
VALUE_TABLE: TableType
STRUCT_FIELD_NAME_FIELD_NUMBER: _ClassVar[int]
struct_field_name: _descriptor.FieldDescriptor
IS_RAW_PROTO_FIELD_NUMBER: _ClassVar[int]
is_raw_proto: _descriptor.FieldDescriptor
IS_HIDDEN_COLUMN_FIELD_NUMBER: _ClassVar[int]
is_hidden_column: _descriptor.FieldDescriptor
IS_MEASURE_FIELD_NUMBER: _ClassVar[int]
is_measure: _descriptor.FieldDescriptor
IS_WRAPPER_FIELD_NUMBER: _ClassVar[int]
is_wrapper: _descriptor.FieldDescriptor
IS_STRUCT_FIELD_NUMBER: _ClassVar[int]
is_struct: _descriptor.FieldDescriptor
TABLE_TYPE_FIELD_NUMBER: _ClassVar[int]
table_type: _descriptor.FieldDescriptor

class WireFormatAnnotationEmptyMessage(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class NormalizeMode(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    NFC: _ClassVar[NormalizeMode]
    NFKC: _ClassVar[NormalizeMode]
    NFD: _ClassVar[NormalizeMode]
    NFKD: _ClassVar[NormalizeMode]
NFC: NormalizeMode
NFKC: NormalizeMode
NFD: NormalizeMode
NFKD: NormalizeMode



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/common/reflection.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/common/reflection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fzetasql/common/reflection.proto\x12\x12zetasql.reflection\"_\n\x06\x43olumn\x12\x13\n\x0btable_alias\x18\x01 \x01(\t\x12\x13\n\x0b\x63olumn_name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x1d\n\x15is_value_table_column\x18\x04 \x01(\x08\"K\n\nTableAlias\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x63olumn_name\x18\x02 \x03(\t\x12\x1a\n\x12pseudo_column_name\x18\x03 \x03(\t\"\x8e\x02\n\x0bResultTable\x12*\n\x06\x63olumn\x18\x01 \x03(\x0b\x32\x1a.zetasql.reflection.Column\x12\x31\n\rpseudo_column\x18\x02 \x03(\x0b\x32\x1a.zetasql.reflection.Column\x12\x33\n\x0btable_alias\x18\x03 \x03(\x0b\x32\x1e.zetasql.reflection.TableAlias\x12?\n\x17\x63ommon_table_expression\x18\x04 \x03(\x0b\x32\x1e.zetasql.reflection.TableAlias\x12\x16\n\x0eis_value_table\x18\x05 \x01(\x08\x12\x12\n\nis_ordered\x18\x06 \x01(\x08\x42\x02P\x01\x62\x08\x65\x64itionsp\xe8\x07')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.common.reflection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'P\001'
  _globals['_COLUMN']._serialized_start=55
  _globals['_COLUMN']._serialized_end=150
  _globals['_TABLEALIAS']._serialized_start=152
  _globals['_TABLEALIAS']._serialized_end=227
  _globals['_RESULTTABLE']._serialized_start=230
  _globals['_RESULTTABLE']._serialized_end=500
# @@protoc_insertion_point(module_scope)



from zetasql.wasi._pb2.zetasql.public import error_location_pb2 as _error_location_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class InternalErrorLocation(_message.Message):
    __slots__ = ("byte_offset", "filename", "error_source")
    BYTE_OFFSET_FIELD_NUMBER: _ClassVar[int]
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    ERROR_SOURCE_FIELD_NUMBER: _ClassVar[int]
    byte_offset: int
    filename: str
    error_source: _containers.RepeatedCompositeFieldContainer[_error_location_pb2.ErrorSource]
    def __init__(self, byte_offset: _Optional[int] = ..., filename: _Optional[str] = ..., error_source: _Optional[_Iterable[_Union[_error_location_pb2.ErrorSource, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/simple_model.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/simple_model.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import simple_table_pb2 as zetasql_dot_public_dot_simple__table__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!zetasql/public/simple_model.proto\x12\x07zetasql\x1a!zetasql/public/simple_table.proto\"\x83\x01\n\x10SimpleModelProto\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12)\n\x05input\x18\x03 \x03(\x0b\x32\x1a.zetasql.SimpleColumnProto\x12*\n\x06output\x18\x04 \x03(\x0b\x32\x1a.zetasql.SimpleColumnProtoB\'\n\x12\x63om.google.zetasqlB\x11SimpleModelProtos')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.simple_model_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\021SimpleModelProtos'
  _globals['_SIMPLEMODELPROTO']._serialized_start=82
  _globals['_SIMPLEMODELPROTO']._serialized_end=213
# @@protoc_insertion_point(module_scope)



"""TableBuilder - Fluent API for building SimpleTable ProtoModel objects."""

from typing_extensions import Self

from zetasql.types import SimpleColumn, SimpleTable, Type, TypeKind

from ._helpers import convert_to_type


class TableBuilder:
    """Builder for SimpleTable ProtoModel objects.

    Args:
        name: Table name
        serialization_id: Optional table ID
    """

    def __init__(self, name: str, serialization_id: int | None = None):
        self._table = SimpleTable(name=name, serialization_id=serialization_id, column=[])

    def add_column(self, name: str, type_or_kind: Type | TypeKind | int) -> Self:
        """Add a column to the table."""
        column_type = convert_to_type(type_or_kind)
        column = SimpleColumn(name=name, type=column_type, is_writable_column=True)
        self._table.column.append(column)
        return self

    def with_serialization_id(self, serialization_id: int) -> Self:
        """Set serialization ID."""
        self._table.serialization_id = serialization_id
        return self

    def as_value_table(self) -> Self:
        """Mark table as a value table."""
        self._table.is_value_table = True
        return self

    def build(self) -> SimpleTable:
        """Build and return the SimpleTable ProtoModel."""
        return self._table


__all__ = ["TableBuilder"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/type_annotation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/type_annotation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public.proto import type_annotation_pb2 as zetasql_dot_public_dot_proto_dot_type__annotation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$zetasql/public/type_annotation.proto\x12\x0fzetasql.storage\x1a*zetasql/public/proto/type_annotation.protoB\x1e\n\x12\x63om.google.zetasql\xa2\x02\x07ZETASQL')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.type_annotation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasql\242\002\007ZETASQL'
# @@protoc_insertion_point(module_scope)



"""FunctionBuilder - Fluent API for building Function ProtoModel objects."""

from typing_extensions import Self

from zetasql.types import (
    Function,
    FunctionArgumentType,
    FunctionArgumentTypeOptions,
    FunctionEnums,
    FunctionSignature,
    SignatureArgumentKind,
    Type,
    TypeKind,
)

from ._helpers import convert_to_type


class FunctionBuilder:
    """Builder for Function ProtoModel objects.

    Args:
        name: Function name (can be multi-part like "pkg.MY_UDF")
        group: Function group (default: "UDF")
        mode: Function mode (default: SCALAR)
    """

    def __init__(
        self,
        name: str,
        group: str = "UDF",
        mode: FunctionEnums.Mode = FunctionEnums.Mode.SCALAR,
    ):
        name_path = name.split(".")
        self._function = Function(name_path=name_path, group=group, mode=mode, signature=[])

    def set_group(self, group: str) -> Self:
        """Set function group."""
        self._function.group = group
        return self

    def set_mode(self, mode: FunctionEnums.Mode) -> Self:
        """Set function mode."""
        self._function.mode = mode
        return self

    def add_signature(self, signature: FunctionSignature) -> Self:
        """Add a function signature (allows overloading)."""
        self._function.signature.append(signature)
        return self

    def build(self) -> Function:
        """Build and return the Function ProtoModel."""
        return self._function


class SignatureBuilder:
    """Builder for FunctionSignature ProtoModel objects."""

    def __init__(self):
        self._signature = FunctionSignature(argument=[], return_type=None)

    def add_argument(
        self,
        type_or_kind: Type | TypeKind | int,
        cardinality: FunctionEnums.ArgumentCardinality = FunctionEnums.ArgumentCardinality.REQUIRED,
    ) -> Self:
        """Add an argument to the signature."""
        arg = self._create_argument_type(type_or_kind, cardinality)
        self._signature.argument.append(arg)
        return self

    def set_return_type(self, type_or_kind: Type | TypeKind | int) -> Self:
        """Set the return type of the signature."""
        self._signature.return_type = self._create_argument_type(type_or_kind)
        return self

    def build(self) -> FunctionSignature:
        """Build and return the FunctionSignature ProtoModel."""
        return self._signature

    @staticmethod
    def _create_argument_type(
        type_or_kind: Type | TypeKind | int,
        cardinality: FunctionEnums.ArgumentCardinality = FunctionEnums.ArgumentCardinality.REQUIRED,
    ) -> FunctionArgumentType:
        """Create a FunctionArgumentType from a Type or TypeKind."""
        arg_type = convert_to_type(type_or_kind)
        return FunctionArgumentType(
            kind=SignatureArgumentKind.ARG_TYPE_FIXED,
            type=arg_type,
            options=FunctionArgumentTypeOptions(cardinality=cardinality),
        )


__all__ = ["FunctionBuilder", "SignatureBuilder"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/public/constness_level.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/public/constness_level.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$zetasql/public/constness_level.proto\x12\x07zetasql\"\xa4\x01\n\x13\x43onstnessLevelProto\"\x8c\x01\n\x05Level\x12\x19\n\x15\x43ONSTNESS_UNSPECIFIED\x10\x00\x12\x11\n\rFOREVER_CONST\x10\x01\x12\x12\n\x0e\x41NALYSIS_CONST\x10\x02\x12 \n\x1bLEGACY_LITERAL_OR_PARAMETER\x10\xe8\x07\x12\x1f\n\x1aLEGACY_CONSTANT_EXPRESSION\x10\xe9\x07\x42,\n\x12\x63om.google.zetasqlB\x14\x43onstnessLevelProtosP\x01')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.public.constness_level_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\024ConstnessLevelProtosP\001'
  _globals['_CONSTNESSLEVELPROTO']._serialized_start=50
  _globals['_CONSTNESSLEVELPROTO']._serialized_end=214
  _globals['_CONSTNESSLEVELPROTO_LEVEL']._serialized_start=74
  _globals['_CONSTNESSLEVELPROTO_LEVEL']._serialized_end=214
# @@protoc_insertion_point(module_scope)



from zetasql.wasi._pb2.zetasql.public import error_location_pb2 as _error_location_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FixRange(_message.Message):
    __slots__ = ("start", "length")
    START_FIELD_NUMBER: _ClassVar[int]
    LENGTH_FIELD_NUMBER: _ClassVar[int]
    start: _error_location_pb2.ErrorLocation
    length: int
    def __init__(self, start: _Optional[_Union[_error_location_pb2.ErrorLocation, _Mapping]] = ..., length: _Optional[int] = ...) -> None: ...

class TextEdit(_message.Message):
    __slots__ = ("range", "new_text")
    RANGE_FIELD_NUMBER: _ClassVar[int]
    NEW_TEXT_FIELD_NUMBER: _ClassVar[int]
    range: FixRange
    new_text: str
    def __init__(self, range: _Optional[_Union[FixRange, _Mapping]] = ..., new_text: _Optional[str] = ...) -> None: ...

class Edits(_message.Message):
    __slots__ = ("text_edits",)
    TEXT_EDITS_FIELD_NUMBER: _ClassVar[int]
    text_edits: _containers.RepeatedCompositeFieldContainer[TextEdit]
    def __init__(self, text_edits: _Optional[_Iterable[_Union[TextEdit, _Mapping]]] = ...) -> None: ...

class Fix(_message.Message):
    __slots__ = ("title", "edits")
    TITLE_FIELD_NUMBER: _ClassVar[int]
    EDITS_FIELD_NUMBER: _ClassVar[int]
    title: str
    edits: Edits
    def __init__(self, title: _Optional[str] = ..., edits: _Optional[_Union[Edits, _Mapping]] = ...) -> None: ...

class ErrorFixSuggestions(_message.Message):
    __slots__ = ("fix_suggestions",)
    FIX_SUGGESTIONS_FIELD_NUMBER: _ClassVar[int]
    fix_suggestions: _containers.RepeatedCompositeFieldContainer[Fix]
    def __init__(self, fix_suggestions: _Optional[_Iterable[_Union[Fix, _Mapping]]] = ...) -> None: ...



"""CatalogBuilder - Fluent API for building SimpleCatalog ProtoModel objects."""

from typing_extensions import Self

from zetasql.types import (
    Function,
    SimpleCatalog,
    SimpleConstant,
    SimpleTable,
    TableValuedFunction,
    ZetaSQLBuiltinFunctionOptions,
)


class CatalogBuilder:
    """Builder for SimpleCatalog ProtoModel objects.

    Args:
        name: Catalog name
    """

    def __init__(self, name: str):
        self._catalog = SimpleCatalog(name=name, table=[])

    def add_table(self, table: SimpleTable) -> Self:
        """Add a table to the catalog.

        Raises:
            ValueError: If table with same name already exists (case-insensitive)
        """
        if table.name:
            new_name = table.name.lower()
            for existing in self._catalog.table:
                if existing.name and existing.name.lower() == new_name:
                    raise ValueError(f"Table '{table.name}' already exists in catalog")

        self._catalog.table.append(table)
        return self

    def with_builtin_functions(self, options: ZetaSQLBuiltinFunctionOptions) -> Self:
        """Configure builtin function options."""
        self._catalog.builtin_function_options = options
        return self

    def add_function(self, function: Function) -> Self:
        """Add a custom function to the catalog."""
        self._catalog.add_function(function)
        return self

    def add_table_valued_function(self, tvf: TableValuedFunction) -> Self:
        """Add a table-valued function to the catalog."""
        self._catalog.add_table_valued_function(tvf)
        return self

    def add_constant(self, constant: SimpleConstant) -> Self:
        """Add a constant to the catalog."""
        self._catalog.add_constant(constant)
        return self

    def build(self) -> SimpleCatalog:
        """Build and return the SimpleCatalog ProtoModel."""
        return self._catalog


__all__ = ["CatalogBuilder"]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/proto/placeholder_descriptor.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/proto/placeholder_descriptor.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*zetasql/proto/placeholder_descriptor.proto\x12\x07zetasql\x1a google/protobuf/descriptor.proto\"\x9b\x01\n\x1aPlaceholderDescriptorProto\x12\x16\n\x0eis_placeholder\x18\x01 \x01(\x08\x32\x65\n\x16placeholder_descriptor\x12\x1f.google.protobuf.MessageOptions\x18\xb4m \x01(\x0b\x32#.zetasql.PlaceholderDescriptorProtoB1\n\x12\x63om.google.zetasqlB\x1bPlaceholderDescriptorProtos')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.proto.placeholder_descriptor_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\033PlaceholderDescriptorProtos'
  _globals['_PLACEHOLDERDESCRIPTORPROTO']._serialized_start=90
  _globals['_PLACEHOLDERDESCRIPTORPROTO']._serialized_end=245
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/proto/internal_error_location.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/proto/internal_error_location.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from zetasql.wasi._pb2.zetasql.public import error_location_pb2 as zetasql_dot_public_dot_error__location__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+zetasql/proto/internal_error_location.proto\x12\x07zetasql\x1a#zetasql/public/error_location.proto\"j\n\x15InternalErrorLocation\x12\x13\n\x0b\x62yte_offset\x18\x03 \x01(\x05\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12*\n\x0c\x65rror_source\x18\x05 \x03(\x0b\x32\x14.zetasql.ErrorSourceB1\n\x12\x63om.google.zetasqlB\x1bInternalErrorLocationProtos')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.proto.internal_error_location_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\022com.google.zetasqlB\033InternalErrorLocationProtos'
  _globals['_INTERNALERRORLOCATION']._serialized_start=93
  _globals['_INTERNALERRORLOCATION']._serialized_end=199
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: zetasql/proto/script_exception.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'zetasql/proto/script_exception.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$zetasql/proto/script_exception.proto\x12\x07zetasql\"\x9a\x02\n\x0fScriptException\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x33\n\x08internal\x18\x02 \x01(\x0b\x32!.zetasql.ScriptException.Internal\x1aS\n\x0fStackTraceFrame\x12\x0c\n\x04line\x18\x01 \x01(\x03\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\x03\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x1a\x61\n\x08Internal\x12\x16\n\x0estatement_text\x18\x01 \x01(\t\x12=\n\x0bstack_trace\x18\x02 \x03(\x0b\x32(.zetasql.ScriptException.StackTraceFrame*\t\x08\x90N\x10\x80\x80\x80\x80\x02')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'zetasql.proto.script_exception_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SCRIPTEXCEPTION']._serialized_start=50
  _globals['_SCRIPTEXCEPTION']._serialized_end=332
  _globals['_SCRIPTEXCEPTION_STACKTRACEFRAME']._serialized_start=139
  _globals['_SCRIPTEXCEPTION_STACKTRACEFRAME']._serialized_end=222
  _globals['_SCRIPTEXCEPTION_INTERNAL']._serialized_start=224
  _globals['_SCRIPTEXCEPTION_INTERNAL']._serialized_end=321
# @@protoc_insertion_point(module_scope)



class TypeKindMixin:
    """Mixin class providing helper methods for TypeKind enum.

    This should be mixed into TypeKind IntEnum to provide type checking
    convenience methods while maintaining IDE autocomplete support.
    """

    def is_simple(self) -> bool:
        """Returns true if this is a simple (non-composite) type."""
        from zetasql.types.proto_model import TypeKind

        return self not in (
            TypeKind.TYPE_ARRAY,
            TypeKind.TYPE_STRUCT,
            TypeKind.TYPE_PROTO,
            TypeKind.TYPE_ENUM,
            TypeKind.TYPE_RANGE,
            TypeKind.TYPE_MAP,
            TypeKind.TYPE_GRAPH_ELEMENT,
            TypeKind.TYPE_GRAPH_PATH,
            TypeKind.TYPE_MEASURE,
        )

    def is_integer(self) -> bool:
        """Returns true for any integer type (signed or unsigned).

        Note: Named is_integer() instead of is_integer() to avoid conflict
        with int.is_integer() method.
        """
        from zetasql.types.proto_model import TypeKind

        return self in (
            TypeKind.TYPE_INT32,
            TypeKind.TYPE_INT64,
            TypeKind.TYPE_UINT32,
            TypeKind.TYPE_UINT64,
        )

    def is_signed_integer(self) -> bool:
        """Returns true for signed integer types."""
        from zetasql.types.proto_model import TypeKind

        return self in (TypeKind.TYPE_INT32, TypeKind.TYPE_INT64)

    def is_unsigned_integer(self) -> bool:
        """Returns true for unsigned integer types."""
        from zetasql.types.proto_model import TypeKind

        return self in (TypeKind.TYPE_UINT32, TypeKind.TYPE_UINT64)

    def is_floating_point(self) -> bool:
        """Returns true for floating point types."""
        from zetasql.types.proto_model import TypeKind

        return self in (TypeKind.TYPE_FLOAT, TypeKind.TYPE_DOUBLE)

    def is_numerical(self) -> bool:
        """Returns true for any numeric type (integer, float, or decimal)."""
        from zetasql.types.proto_model import TypeKind

        return (
            self.is_integer() or self.is_floating_point() or self in (TypeKind.TYPE_NUMERIC, TypeKind.TYPE_BIGNUMERIC)
        )

    def is_temporal(self) -> bool:
        """Returns true for date/time types."""
        from zetasql.types.proto_model import TypeKind

        return self in (
            TypeKind.TYPE_DATE,
            TypeKind.TYPE_TIME,
            TypeKind.TYPE_DATETIME,
            TypeKind.TYPE_TIMESTAMP,
            TypeKind.TYPE_INTERVAL,
        )

    def is_composite(self) -> bool:
        """Returns true for composite types (array, struct, map, etc)."""
        return not self.is_simple()
